==> xl-react-components-0.16.62.tgz: package/app/pages/buttons-page/button-initial-state.js <==
export const modelActions = (modelName, updateModel) => ({
    action: updateModel(modelName, 'Execute'),
    label: 'Execute',
    subActions: [
        {action: updateModel(modelName, 'One'), label: 'One'},
        {action: updateModel(modelName, 'Two'), label: 'Two'},
        {action: updateModel(modelName, 'Three'), disabled: true, label: 'Three'}
    ]
});

export const modelActionsForDropdownOnlyButton = (modelName, updateModel) => ({
    label: 'Import package',
    subActions: [
        {action: () => updateModel(modelName, 'Header'), header: true, key: 'Header', label: 'Header'},
        {action: () => updateModel(modelName, 'One'), label: 'One'},
        {action: () => updateModel(modelName, 'Two'), label: 'Two'},
        {action: () => updateModel(modelName, 'sep2'), label: 'sep2', separator: true},
        {action: () => updateModel(modelName, 'Three'), disabled: true, label: 'Three'}
    ]
});

export const modelActionsForToggleButton = [
    {label: 'Zero', value: 0},
    {label: 'One', value: 1},
    {label: 'Two', value: 2}
];

export const buttonsState = {
    debouncedButton1: {
        className: 'debounced-button',
        model: 1,
        modelName: 'debouncedButton1',
        navigationDescription: 'xl-react-button',
        navigationTitle: 'Debounced Button'
    },
    primaryButton: {
        className: 'split-button-with-dropdown-primary',
        model: '',
        modelName: 'primaryButton',
        navigationDescription: 'xl-react-button-with-dropdown',
        navigationTitle: 'Split Button with Dropdown (Primary)'
    },
    primaryDropdownOnlyButton: {
        className: 'button-with-dropdown-primary',
        model: '',
        modelName: 'primaryDropdownOnlyButton',
        navigationDescription: 'xl-react-button-with-dropdown',
        navigationTitle: 'Button with just Dropdown (Primary)'
    },
    secondaryButton: {
        className: 'split-button-with-dropdown-secondary',
        model: '',
        modelName: 'secondaryButton',
        navigationDescription: 'xl-react-button-with-dropdown',
        navigationTitle: 'Split Button with Dropdown (Secondary)'
    },
    secondaryDropdownOnlyButton: {
        className: 'button-with-dropdown-secondary',
        model: '',
        modelName: 'secondaryDropdownOnlyButton',
        navigationDescription: 'xl-react-button-with-dropdown',
        navigationTitle: 'Button with just Dropdown (Secondary)'
    },
    toggleButton: {
        className: 'button-with-dropdown-primary',
        model: '',
        modelName: 'toggleButton',
        navigationDescription: 'xl-react-toggle-button',
        navigationTitle: 'Toggle Button with one active state'
    }
};

==> xl-react-components-0.21.15.tgz: package/app/pages/buttons-page/button-initial-state.js <==
export const modelActions = (modelName, updateModel) => ({
    action: updateModel(modelName, 'Execute'),
    labelRenderer: () => 'Execute',
    subActions: [
        {action: updateModel(modelName, 'One'), labelRenderer: () => 'One', title: 'One'},
        {action: updateModel(modelName, 'Two'), labelRenderer: () => 'Two', title: 'Two'},
        {action: updateModel(modelName, 'Three'), disabled: true, labelRenderer: () => 'Three', title: 'Three'}
    ]
});

export const modelActionsForDropdownOnlyButton = (modelName, updateModel) => ({
    labelRenderer: () => 'Import package',
    subActions: [
        {
            action: () => updateModel(modelName, 'Header'),
            header: true,
            key: 'Header',
            labelRenderer: () => 'Header',
            title: 'Header'
        },
        {action: () => updateModel(modelName, 'One'), labelRenderer: () => 'One', title: 'One'},
        {action: () => updateModel(modelName, 'Two'), labelRenderer: () => 'Two', title: 'Two'},
        {action: () => updateModel(modelName, 'sep2'), labelRenderer: () => 'sep2', separator: true, title: 'sep2'},
        {action: () => updateModel(modelName, 'Three'), disabled: true, labelRenderer: () => 'Three', title: 'Three'}
    ]
});

export const modelActionsForToggleButton = [
    {label: 'Zero', value: 0},
    {label: 'One', value: 1},
    {label: 'Two', value: 2}
];

export const buttonsState = {
    debouncedButton1: {
        className: 'debounced-button',
        model: 1,
        modelName: 'debouncedButton1',
        navigationDescription: 'xl-react-button',
        navigationTitle: 'Debounced Button'
    },
    primaryButton: {
        className: 'split-button-with-dropdown-primary',
        model: '',
        modelName: 'primaryButton',
        navigationDescription: 'xl-react-button-with-dropdown',
        navigationTitle: 'Split Button with Dropdown (Primary)'
    },
    primaryDropdownOnlyButton: {
        className: 'button-with-dropdown-primary',
        model: '',
        modelName: 'primaryDropdownOnlyButton',
        navigationDescription: 'xl-react-button-with-dropdown',
        navigationTitle: 'Button with just Dropdown (Primary)'
    },
    secondaryButton: {
        className: 'split-button-with-dropdown-secondary',
        model: '',
        modelName: 'secondaryButton',
        navigationDescription: 'xl-react-button-with-dropdown',
        navigationTitle: 'Split Button with Dropdown (Secondary)'
    },
    secondaryDropdownOnlyButton: {
        className: 'button-with-dropdown-secondary',
        model: '',
        modelName: 'secondaryDropdownOnlyButton',
        navigationDescription: 'xl-react-button-with-dropdown',
        navigationTitle: 'Button with just Dropdown (Secondary)'
    },
    toggleButton: {
        className: 'button-with-dropdown-primary',
        model: '',
        modelName: 'toggleButton',
        navigationDescription: 'xl-react-toggle-button',
        navigationTitle: 'Toggle Button with one active state'
    }
};
